// Copyright (c) 2023 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "events/VNTextEventParser.hpp"
#include "events/VNPositionEventParser.hpp"

namespace Dawn {
  enum VNSceneEventType {
    VN_SCENE_EVENT_TYPE_TEXT,
    VN_SCENE_EVENT_TYPE_POSITION
  };

  struct VNSceneEvent {
    enum VNSceneEventType type;
    
    struct VNTextEvent text;
    struct VNPositionEvent position;
  };

  struct VNSceneEventList {
    std::vector<struct VNSceneEvent> events;
  };

  class VNSceneEventsParser : public XmlParser<struct VNSceneEventList> {
    protected:
      std::vector<std::string> getRequiredAttributes() override;
      std::map<std::string, std::string> getOptionalAttributes() override;
      int32_t onParse(
        Xml *node,
        std::map<std::string, std::string> values,
        struct VNSceneEventList *out,
        std::string *error
      ) override;
  };
}